# Authors

## Lead


* Derrick Gilland, [dgilland@gmail.com](mailto:dgilland@gmail.com), [dgilland@github](https://github.com/dgilland)

## Contributors


* Nathan Cahill, [nathan@nathancahill.com](mailto:nathan@nathancahill.com), [nathancahill@github](https://github.com/nathancahill)


* Klaus Sevensleeper, [k7sleeper@gmail.com](mailto:k7sleeper@gmail.com), [k7sleeper@github](https://github.com/k7sleeper)


* Bharadwaj Yarlagadda, [yarlagaddabharadwaj@gmail.com](mailto:yarlagaddabharadwaj@gmail.com), [bharadwajyarlagadda@github](https://github.com/bharadwajyarlagadda)


* Michael James, [urbnjamesmi1@github](https://github.com/urbnjamesmi1)


* Tim Griesser, [tgriesser@gmail.com](mailto:tgriesser@gmail.com), [tgriesser@github](https://github.com/tgriesser)


* Shaun Patterson, [shaunpatterson@github](https://github.com/shaunpatterson)


* Brian Beck, [beck3905@github](https://github.com/beck3905)


* Frank Epperlein, [efenka@github](https://github.com/efenka)


* Joshua Wilson, [jwilson8767@github](https://github.com/jwilson8767)


* Eli Jose, [elijose55@github](https://github.com/elijose55)


* Gonzalo Naveira, [gonzalonaveira@github](https://github.com/gonzalonaveira)


* Wenbo Zhao, [zhaowb@gmail.com](mailto:zhaowb@gmail.com), [zhaowb@github](https://github.com/zhaowb)


* Mervyn Lee, [mervynlee94@github](https://github.com/mervynlee94)


* Weineel Lee, [weineel@github](https://github.com/weineel)
